<template>
  <el-container>

    <el-aside>
      <basic-container>
        <div ref="TreeBox" style="height: calc(100vh - 144px);!important;">
          <div class="headerCon">
            <el-button icon="el-icon-plus" plain size="small" type="primary" @click="addClickHandler">创建
            </el-button>
            <el-button icon="el-icon-edit" plain size="small" type="primary" @click="editClickHandler">修改
            </el-button>
            <el-button icon="el-icon-delete" plain size="small" type="danger" @click="delClickHandler">删除
            </el-button>
            <el-button icon="el-icon-download" plain size="small" type="primary" @click="exportClickHandler">导出
            </el-button>
            <el-button icon="el-icon-upload2" plain size="small" type="primary" @click="uploadClickHandler">导入
            </el-button>
            <el-button class="smallBtn" plain size="small" type="primary"
                       @click="checkViewClickHandler">查看使用范围
            </el-button>
          </div>
          <!-- 左侧树         -->
          <div style="height:  calc(100vh - 280px);">
            <avue-tree :data="treeData" :option="treeOption" @node-click="nodeClick">
          <span slot-scope="{ node, data }" class="el-tree-node__label">
           <span style="font-size: 15px">
              <i class="el-icon-s-promotion"></i>
                {{ (node || {}).label }}
            </span>
          </span>
            </avue-tree>
          </div>
        </div>
      </basic-container>
    </el-aside>

    <el-main>
      <basic-container>
        <el-descriptions :column="1" border class="margin-top" size="medium" title="属性信息">
          <el-descriptions-item :contentStyle="descriptionOption.contentStyle"
                                :labelStyle="descriptionOption.labelStyle">
            <template slot="label">
              <i :class="icons.id"></i>
              名称
            </template>
            <el-tag v-if="nodeRow.id">{{ nodeRow.id }}</el-tag>
          </el-descriptions-item>
          <el-descriptions-item :contentStyle="descriptionOption.contentStyle"
                                :labelStyle="descriptionOption.labelStyle">
            <template slot="label">
              <i :class="icons.name"></i>
              标签
            </template>
            <el-tag v-if="nodeRow.name">{{ nodeRow.name }}</el-tag>
          </el-descriptions-item>
          <el-descriptions-item :contentStyle="descriptionOption.contentStyle"
                                :labelStyle="descriptionOption.labelStyle">
            <template slot="label">
              <i :class="icons.desc"></i>
              描述
            </template>
            <el-tag v-if="nodeRow.description">{{ nodeRow.description }}</el-tag>
          </el-descriptions-item>
        </el-descriptions>
<!--        <avue-crud>-->
<!--          :data="data"-->
<!--          :option="option"-->
<!--        </avue-crud>-->
      </basic-container>
    </el-main>

    <!-- 新增 修改 -->
    <el-dialog
      v-dialogDrag
      :title="dialogTitle === 'add' ? '创建' : '修改'"
      :visible.sync="visible"
      append-to-body="true"
      class="avue-dialog"
      width="40%"
      @close="visibleCloseHandler"
    >
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-row>
          <el-col :span="24">
            <el-form-item label="名称：" prop="id">
              <el-input v-model="form.id"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="标签：" prop="name">
              <el-input v-model="form.name"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="描述：" prop="description">
              <el-input v-model="form.description" :rows="2" type="textarea"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
         <el-button @click="visibleCloseHandler">取 消</el-button>
         <el-button type="primary" @click="addSaveHandler">确 定</el-button>
        </span>
    </el-dialog>

    <!-- 导入 -->
    <upload-file ref="upload" :fileType="upFileType" :fileUrl="fileUrl" :tipList="tipList" title="导入"
                 @updata="getTreeList"></upload-file>

    <!-- 查看使用范围 -->
    <el-dialog
      v-dialogDrag
      :visible.sync="checkViewVisible"
      append-to-body="true"
      class="avue-dialog"
      title="查看使用范围"
      width="60%"
    >
      <avue-crud
        ref="checkViewCrud"
        :data="checkViewData"
        :option="checkViewOption"
        :table-loading="checkViewLoading"
        @search-change="checkHandleSearch"
        @search-reset="checkHandleReset"
      >
      </avue-crud>
    </el-dialog>

  </el-container>

</template>

<script>
import {gridStatus, addSave, editSave, deleteStatus, exportStatus, listUsed} from "@/api/modeling/statusPool/api";
import func from "@/util/func";
import basicOption from "@/util/basic-option";

export default {
  name: "index",
  data() {
    return {
      data:[],
      option:{
        ...basicOption
      },
      checkViewVisible: false,
      checkViewData: [],
      checkViewDataSearch: [],
      checkViewLoading: false,
      checkViewOption: {
        ...basicOption,
        addBtn: false,
        menu: false,
        searchMenuSpan: 8,
        refreshBtn: false,
        selection: false,
        column: [
          {
            label: '名称',
            prop: 'TreeId',
            sortable: true,
          },
          {
            label: '来源',
            prop: 'name',
            sortable: true,
            search: true
          },
          {
            label: '说明',
            prop: 'description',
          }
        ]
      },
      tipList: [
        "请注意名称不能为空",
      ],
      upFileType: ['xls', 'xlsx'],
      fileUrl: 'api/statusController/importStatus',
      dialogTitle: '',
      form: {
        id: "",
        name: "",
        description: ""
      },
      rules: {
        id: [
          {required: true, message: '请输入名称', trigger: 'blur'},
        ]
      },
      visible: false,
      treeOption: {
        height: 'auto',
        defaultExpandAll: false,
        menu: false,
        addBtn: false,
        props: {
          label: 'id',
          value: 'id',
          children: 'children'
        }
      },
      treeData: [],
      nodeRow: {},
      descriptionOption: {
        labelStyle: 'text-align:center;width:120px',
        contentStyle: 'width:240px;text-align:center;word-break;break-all;'
      },
      icons: {
        id: 'el-icon-finished',
        name: 'el-icon-tickets',
        desc: 'el-icon-chat-line-square'
      },
    }
  },
  created() {
    this.getTreeList();
  },
  methods: {
    // 左侧树请求
    getTreeList() {
      gridStatus({page: 1, limit: -1}).then(res => {
        const data = res.data.data;
        this.treeData = data;
      }).catch(err => {
        this.$message.error(err)
      });
    },

    // 树节点点击事件
    nodeClick(row) {
      this.nodeRow = row;
    },

    // 创建按钮
    addClickHandler() {
      this.visible = true;
      this.dialogTitle = 'add';
    },

    // 编辑按钮
    editClickHandler() {
      if (func.isEmptyObject(this.nodeRow)) {
        this.$message.error('请至少选择一条数据！');
        return;
      }
      this.visible = true;
      this.dialogTitle = 'edit';
      this.form = this.nodeRow;
    },

    // 删除
    delClickHandler() {
      if (func.isEmptyObject(this.nodeRow)) {
        this.$message.error('请至少选择一条数据！');
        return;
      }
      this.$confirm('您确定要删除所选择的数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        const list = [this.nodeRow];
        deleteStatus(list).then(res => {
          if (res.data.code === 200) {
            this.$message.success(res.data.obj);
            this.getTreeList();
            this.nodeRow = {};
          }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },

    // 关闭对话框
    visibleCloseHandler() {
      const form = {
        id: "",
        name: "",
        imagePath: "",
        description: ""
      }
      this.form = form;
      this.visible = false;
      this.$refs.form.clearValidate();
    },

    // 创建或编辑保存
    addSaveHandler() {
      const saveFunction = this.dialogTitle === 'add' ? addSave : editSave;

      saveFunction(this.form).then(res => {
        if (res.data.code === 200) {
          this.$message.success(res.data.obj);
          this.getTreeList();
          this.visible = false;
        } else {
          this.$message.error(res.data.obj);
        }
      }).catch(error => {
        this.$message.error(error);
      });
    },

    // 导出
    exportClickHandler() {
      if (func.isEmptyObject(this.nodeRow)) {
        this.$message.error('请至少选择一条数据！');
        return;
      }

      exportStatus({statusOids: this.nodeRow.oid}).then(res => {
        func.downloadFileByBlobHandler(res);
        this.$message.success('导出成功');
      }).catch(err => {
        this.$message.error(err);
      })
    },

    // 导入
    uploadClickHandler() {
      this.$refs.upload.visible = true;
    },

    // 查看使用范围
    checkViewClickHandler() {
      if (func.isEmptyObject(this.nodeRow)) {
        this.$message.error('请至少选择一条数据！');
        return;
      }
      listUsed({oid: this.nodeRow.oid}).then(res => {
        if (res.data.code === 200) {
          this.checkViewVisible = true;
          const data = res.data.data;
          data.forEach(item => {
            item.name = item.id + `( ${item.name} )`;
            item.TreeId = this.nodeRow.id;
          })
          this.checkViewData = res.data.data;
          this.checkViewDataSearch = res.data.data;
        }
      })
    },
    // 查看使用范围查询
    checkHandleSearch(params, done) {
      const {name} = params;

      if (!params.name) {
        this.checkViewData = this.checkViewDataSearch;
        return done();
      }
      ;

      this.checkViewData = this.checkViewData.filter(item => {
        return item.name && item.name.includes(name);
      });

      done();

    },

    // 查看使用范围重置
    checkHandleReset() {
      this.checkViewData = this.checkViewDataSearch;
    },

  }
}
</script>

<style lang="scss" scoped>
::v-deep {
  .el-scrollbar__wrap {
    overflow: auto !important;
  }
  .headerCon{
    .el-button{
      width: 82px;
    }
  }
}

.headerCon {
  display: flex;
  flex-wrap: wrap;
  margin-bottom: 5px;

  .el-button + .el-button {
    margin-left: 5px;
  }

  .el-button {
    margin-top: 5px;
  }
}

.headerCon > .el-button:nth-child(4) {
  margin-left: 0;
}

.headerCon > .el-button:nth-child(7) {
  margin-left: 0;
}

.upload-demo {
  margin-left: 20px;
}

.smallBtn {
  width: 82px;
  text-align: center;
  padding-left: 4.5px;
}
</style>
